## Extrusion instance catalogue

![simple_frame](images/simple_frame.png)

![voronoi](images/voronoi.png)

![mars](images/mars_bubble.png)

![djmm_block](images/djmm_block.png)

![topopt-100](images/topopt-100.png)

![topopt-205](images/topopt-205.png)

![topopt-310](images/topopt-310.png)

![art-opt_bunny](images/art-opt_bunny.png)

![bunny_tri](images/bunny_full_tri.PNG)

![bunny_tri_dense](images/bunny_full_tri_dense.PNG)

![bunny_quad](images/bunny_full_quad.PNG)

![duck.PNG](images/duck.PNG)

![fandisk.PNG](images/fandisk.PNG)

![fertility.PNG](images/fertility.PNG)

![klein_bottle.PNG](images/klein_bottle.PNG)

![trifoilknot.PNG](images/trifoilknot.PNG)

![semi_sphere.PNG](images/semi_sphere.PNG)

![david.PNG](images/david.PNG)

![C_shape.PNG](images/C_shape.PNG)